@@ -1,5 +1,5 @@
 #    https://launchpad.net/wxbanker
-#    accountlistctrl.py: Copyright 2007-2009 Mike Rooney <mrooney@ubuntu.com>
+#    accountlistctrl.py: Copyright 2007-2010 Mike Rooney <mrooney@ubuntu.com>
 #
 #    This file is part of wxBanker.
 #
@@ -24,7 +24,7 @@ from wx.lib.pubsub import Publisher
 class AccountListCtrl(wx.Panel):
     """
     This control manages a clickable list of accounts,
-    displaying their totals to the right of them
+    displaying their totals to the right of them,
     as well as the grand total as the last entry.
 
     Accounts can be added, removed, and renamed.
@@ -38,7 +38,7 @@ class AccountListCtrl(wx.Panel):
         # Initialize some attributes to their default values.
         self.editCtrl = self.hiddenIndex = None
         self.currentIndex = None
-        self.hyperLinks, self.totalTexts, self.accountObjects = [], [], []
+        self.radioButtons, self.totalTexts, self.accountObjects, self.mintStatuses = [], [], [], []
 
         # Create the staticboxsizer which is the home for everything.
         # This *MUST* be created first to ensure proper z-ordering (as per docs).
@@ -110,6 +110,7 @@ class AccountListCtrl(wx.Panel):
         # Subscribe to messages we are concerned about.
         Publisher.subscribe(self.onAccountBalanceChanged, "ormobject.updated.Account.Balance")
         Publisher.subscribe(self.onAccountRenamed, "ormobject.updated.Account.Name")
+        Publisher.subscribe(self.onAccountMintIdChanged, "ormobject.updated.Account.MintId")
         Publisher.subscribe(self.onAccountRemoved, "account.removed")
         Publisher.subscribe(self.onAccountAdded, "account.created")
         Publisher.subscribe(self.onCurrencyChanged, "currency_changed")
@@ -117,6 +118,8 @@ class AccountListCtrl(wx.Panel):
         Publisher.subscribe(self.onAccountChanged, "user.account changed")
         Publisher.subscribe(self.onSelectNextAccount, "user.next account")
         Publisher.subscribe(self.onSelectPreviousAccount, "user.previous account")
+        Publisher.subscribe(self.onToggleMintIntegration, "user.mint.toggled")
+        Publisher.subscribe(self.onMintDataUpdated, "mint.updated")
 
         # Populate ourselves initially unless explicitly told not to.
         if autoPopulate:
@@ -141,6 +144,22 @@ class AccountListCtrl(wx.Panel):
 
         if not self.GetCount():
             self.addButton.StartFlashing()
+            
+    def onAccountMintIdChanged(self, message):
+        self._UpdateMintStatuses()
+        
+    def _UpdateMintStatuses(self):
+        for account, mintCtrl in zip(self.accountObjects, self.mintStatuses):
+            bitmapName = "transparent"
+            tooltip = _("Not synchronized with Mint.com")
+            if account.IsMintEnabled():
+                tooltip = account.GetSyncString()
+                if account.IsInSync():
+                    bitmapName = "accept"
+                else:
+                    bitmapName = "exclamation"
+            mintCtrl.SetBitmap(wx.ArtProvider.GetBitmap("wxART_%s" % bitmapName))
+            mintCtrl.SetToolTipString(tooltip)
 
     def onCurrencyChanged(self, message):
         # Update all the accounts.
@@ -149,6 +168,30 @@ class AccountListCtrl(wx.Panel):
         # Update the total text.
         self.updateGrandTotal()
         self.Parent.Layout()
+        
+    def onToggleMintIntegration(self, message):
+        enabled = message.data
+        if enabled:
+            self.ConfigureCurrentAccount(tab="mint")
+            # Refresh everything in the case of a cancel which won't trigger an update event.
+            self.onMintDataUpdated()
+        else:
+            self.ShowMintStatus(False)
+           
+    def onMintDataUpdated(self, message=None):
+        self.ShowMintStatus(True)
+        self._UpdateMintStatuses()
+        # A zero-balance account could be out of/ in sync, potentially toggling its visibility.
+        self.refreshVisibility()
+        
+    def ShowMintStatus(self, show):
+        for index, mintStatus in enumerate(self.mintStatuses):
+            if self.IsVisible(index):
+                mintStatus.Show(show)
+        self.Layout()
+        
+    def MintStatusIsShown(self):
+        return self.Model.MintEnabled
 
     def IsVisible(self, index):
         """Return whether or not the account at the given index is visible."""
@@ -169,7 +212,7 @@ class AccountListCtrl(wx.Panel):
         else:
             account = self.accountObjects[index]
             # Set the value in case it wasn't a click that triggered this.
-            self.hyperLinks[index].Value = True
+            self.radioButtons[index].Value = True
 
         self.currentIndex = index
         # Update the remove/edit buttons.
@@ -256,6 +299,10 @@ class AccountListCtrl(wx.Panel):
         else: # Not necessary, but explicit is clearer here.
             return None
 
+    def ConfigureCurrentAccount(self, tab="default"):
+        dlg = accountconfigdialog.AccountConfigDialog(self, self.GetCurrentAccount(), tab)
+        dlg.ShowModal()
+
     def onAccountRemoved(self, message):
         """
         Called when an account is removed from the model.
@@ -293,21 +340,26 @@ class AccountListCtrl(wx.Panel):
         link = wx.RadioButton(self.childPanel, label=account.Name)
         link.AccountIndex = index
         totalText = wx.StaticText(self.childPanel, label=account.float2str(balance))
+        mintStatus = wx.StaticBitmap(self.childPanel)
+        mintStatus.Show(self.Model.MintEnabled)
+        
         self.accountObjects.insert(index, account)
-        self.hyperLinks.insert(index, link)
+        self.radioButtons.insert(index, link)
         self.totalTexts.insert(index, totalText)
+        self.mintStatuses.insert(index, mintStatus)
 
         # Put them in an hsizer.
         miniSizer = wx.BoxSizer()
         miniSizer.Add(link, 1, wx.ALIGN_CENTER)
         miniSizer.Add(totalText, 0, wx.ALIGN_CENTER|wx.LEFT, 10)
+        miniSizer.Add(mintStatus, 0, wx.ALIGN_CENTER|wx.LEFT, 3)
         miniSizer.AddSpacer(3)
 
         # Insert the hsizer into the correct position in the list.
         self.childSizer.Insert(index+1, miniSizer, 0, wx.EXPAND|wx.BOTTOM, 3)
 
         # Renumber the links after this.
-        for linkCtrl in self.hyperLinks[index+1:]:
+        for linkCtrl in self.radioButtons[index+1:]:
             linkCtrl.AccountIndex = linkCtrl.AccountIndex+1
         if self.currentIndex >= index:
             self.currentIndex += 1
@@ -319,14 +371,15 @@ class AccountListCtrl(wx.Panel):
         self.Parent.Layout()
 
     def _RemoveItem(self, index, fixSel=True):
-        linkCtrl = self.hyperLinks[index]
+        linkCtrl = self.radioButtons[index]
 
         self.accountObjects.pop(index)
-        del self.hyperLinks[index]
+        del self.radioButtons[index]
         del self.totalTexts[index]
+        del self.mintStatuses[index]
 
         # Renumber the links after this.
-        for linkCtrl in self.hyperLinks[index:]:
+        for linkCtrl in self.radioButtons[index:]:
             linkCtrl.AccountIndex = linkCtrl.AccountIndex-1
 
         # Actually remove (sort of) the account sizer.
@@ -365,9 +418,9 @@ class AccountListCtrl(wx.Panel):
 
         # Handle a zero-balance account going to non-zero or vice-versa.
         self.refreshVisibility()
-
-        self.Layout()
-        self.Parent.Layout()
+        
+        # Refresh sync status
+        self._UpdateMintStatuses()
 
     def updateGrandTotal(self):
         self.totalText.Label = self.Model.float2str( self.Model.Balance )
@@ -463,9 +516,8 @@ class AccountListCtrl(wx.Panel):
                 # Remove the account from the model.
                 account.Remove()
 
-    def onConfigureButton(self, event):
-        dlg = accountconfigdialog.AccountConfigDialog(self, self.GetCurrentAccount())
-        dlg.ShowModal()
+    def onConfigureButton(self, event=None):
+        self.ConfigureCurrentAccount()
 
     def onRenameButton(self, event):
         if self.currentIndex is not None:
@@ -492,12 +544,12 @@ class AccountListCtrl(wx.Panel):
         """Called when an account has been renamed in the model."""
         account = message.data
         # Hide the edit control.
-        self.onHideEditCtrl(restore=False) #ASSUMPTION!
+        self.onHideEditCtrl(restore=False)
         # Just renaming won't put it in the right alpha position, so remove it
         # and add it again, letting _PutAccount handle the ordering.
         self._RemoveItem(self.currentIndex, fixSel=False)
         self.currentIndex = self._PutAccount(account)
-        self.hyperLinks[self.currentIndex].Value = True
+        self.radioButtons[self.currentIndex].Value = True
 
     def onAccountClick(self, event):
         """
@@ -524,6 +576,7 @@ class AccountListCtrl(wx.Panel):
         This method is called when the user checks/unchecks the option to hide zero-balance accounts.
         """
         showZero = self.bankController.ShowZeroBalanceAccounts
+        showMint = self.MintStatusIsShown()
         
         for i, account in enumerate(self.accountObjects):
             # Show it, in the case of calls from updateTotals where a
@@ -531,9 +584,12 @@ class AccountListCtrl(wx.Panel):
             # +1 offset is to take into account the buttons at the top.
             self.childSizer.Show(i+1)
             if not showZero:
-                if abs(account.Balance) < .001:
+                # If the account is out of sync, always show it so as not to hide discrepencies.
+                if abs(account.Balance) < .001 and not account.IsOutOfSync():
                     self.childSizer.Hide(i+1)
 
+        # Restore the Mint status.
+        self.ShowMintStatus(showMint)
         # If we hid the current selection, select the first available.
         if refreshSelection and not showZero and not self.IsVisible(self.currentIndex):
             self.SelectVisibleItem(0)
