@@ -1,5 +1,5 @@
 #    https://launchpad.net/wxbanker
-#    newtransactionctrl.py: Copyright 2007-2009 Mike Rooney <mrooney@ubuntu.com>
+#    newtransactionctrl.py: Copyright 2007-2010 Mike Rooney <mrooney@ubuntu.com>
 #
 #    This file is part of wxBanker.
 #
@@ -337,6 +337,8 @@ class NewTransactionRow(bankcontrols.GBRow):
         # We could see if there are siblings, but they might not have transactions either.
         if account and not account.Transactions:
             self.newButton.StartFlashing()
+            # For a new account, set the description to "Initial balance" as a suggestion/hint (LP: #520285)
+            self.descCtrl.UpdateValue(_("Initial balance"))
         else:
             self.newButton.StopFlashing()
             
@@ -344,7 +346,7 @@ class NewTransactionRow(bankcontrols.GBRow):
         if self.isInitialAccountSet:
             # Also, don't focus if the transaction tab isn't being viewed, otherwise it snaps us back from viewing graphs.
             if account and self.Parent.IsShownOnScreen():
-                self.defaultFocus() 
+                self.defaultFocus()
         else:
             self.isInitialAccountSet = True
 
